@@ -53,6 +53,12 @@ sub constrain_value {
     return 1;
 }
 
+sub _localize_args {
+    my ($self) = @_;
+    
+    return $self->parent->label;
+}
+
 1;
 
 __END__
