@@ -4,38 +4,45 @@ use strict;
 use base 'HTML::FormFu::Constraint';
 use Class::C3;
 
-use Storable qw/ dclone /;
+use List::MoreUtils qw( any none );
+use Storable qw( dclone );
 
-__PACKAGE__->mk_accessors(
-    qw/
-        others
-        attach_errors_to_base
-        attach_errors_to_others
-        attach_errors_to /
-);
+__PACKAGE__->mk_item_accessors( qw(
+    attach_errors_to_base
+    attach_errors_to_others
+) );
+
+__PACKAGE__->mk_accessors( qw(
+    others
+    attach_errors_to
+) );
 
 sub mk_errors {
     my ( $self, $args ) = @_;
 
     my $pass   = $args->{pass};
     my @failed = $args->{failed} ? @{ $args->{failed} } : ();
-    my @names  = $args->{names} ? @{ $args->{names} } : ();
+    my @names  = $args->{names}  ? @{ $args->{names} }  : ();
 
     my $force = $self->force_errors || $self->parent->force_errors;
     my @attach;
 
     if ( $self->attach_errors_to ) {
-        push @attach, @{ $self->attach_errors_to }
-            if !$pass || $force;
+        if ( !$pass || $force ) {
+            push @attach, @{ $self->attach_errors_to };
+        }
     }
     elsif ( $self->attach_errors_to_base || $self->attach_errors_to_others ) {
-        push @attach, $self->nested_name
-            if $self->attach_errors_to_base
-                && ( !$pass || $force );
+        if ( $self->attach_errors_to_base && ( !$pass || $force ) ) {
+            push @attach, $self->nested_name;
+        }
 
-        push @attach, ref $self->others ? @{ $self->others } : $self->others
-            if $self->attach_errors_to_others
-                && ( !$pass || $force );
+        if ( $self->attach_errors_to_others && ( !$pass || $force ) ) {
+            push @attach,
+                  ref $self->others ? @{ $self->others }
+                :                     $self->others
+                ;
+        }
     }
     elsif ($force) {
         push @attach, @names;
@@ -54,9 +61,12 @@ sub mk_errors {
 
         $error->parent($field);
 
-        $error->forced(1)
-            if ( $pass && $force && grep { $name eq $_ } @names )
-            || !grep { $name eq $_ } @failed;
+        if (    ( $pass && $force && any { $name eq $_ } @names )
+                || none { $name eq $_ } @failed
+            )
+        {
+            $error->forced(1);
+        }
 
         push @errors, $error;
     }
@@ -69,8 +79,9 @@ sub clone {
 
     my $clone = $self->next::method(@_);
 
-    $clone->others( dclone $self->others )
-        if ref $self->others;
+    if ( ref $self->others ) {
+        $clone->others( dclone $self->others );
+    }
 
     return $clone;
 }
@@ -120,7 +131,7 @@ Overrides L</attach_errors_to_base> and L</attach_errors_to_others>.
 
 Is a sub-class of, and inherits methods from L<HTML::FormFu::Constraint>
 
-L<HTML::FormFu::FormFu>
+L<HTML::FormFu>
 
 =head1 AUTHOR
 
